import { Component, OnInit, Output, EventEmitter } from '@angular/core';

import { ContactsListsService, ContactsList } from './contacts-lists.service';

@Component({
  selector: 'app-contacts-lists-wrapper',
  template: `
    <div [ngSwitch]="display">
      <div *ngSwitchCase="'list'">
        <div class="btn-row">
          <button (click)="onAdd()">Hinzufügen</button>
        </div>
        <app-contacts-lists
          [contactsLists]="contactsLists" (selected)="selected.emit($event)" (edit)="onEdit($event)"></app-contacts-lists>
      </div>
      <app-add-contacts-list *ngSwitchCase="'add'" (done)="onDone()"></app-add-contacts-list>
      <app-edit-contacts-list *ngSwitchCase="'edit'" (done)="onDone()" [contactsListId]="currentContactsListId"></app-edit-contacts-list>
    </div>
  `,
  styles: ['app-contacts-lists { margin-top: 10px; display: block; }']
})
export class ContactsListsWrapperComponent implements OnInit {
  @Output()
  selected = new EventEmitter<string>();

  contactsLists: Array<ContactsList> = [];
  display = 'list';
  currentContactsListId: string;

  constructor(private contactsListsService: ContactsListsService) {}

  ngOnInit() {
    this.contactsLists = this.contactsListsService.getContactsLists();
  }

  onAdd() {
    this.display = 'add';
  }

  onDone() {
    this.display = 'list';
    this.contactsLists = this.contactsListsService.getContactsLists();
  }

  onEdit(id: string) {
    this.display = 'edit';
    this.currentContactsListId = id;
  }
}
