import { Component, Input, OnChanges, SimpleChanges } from '@angular/core';

import { ContactsService, Contact } from './contacts.service';

@Component({
  selector: 'app-contacts-wrapper',
  template: `
    <div *ngIf="currentContactsListId; else elseBlock">
      <div [ngSwitch]="display">
        <div *ngSwitchCase="'list'">
          <div class="btn-row">
            <button (click)="onAdd()">Hinzufügen</button>
          </div>
          <app-contacts [contacts]="contacts" (edit)="onEdit($event)"></app-contacts>
        </div>
        <app-add-contact *ngSwitchCase="'add'" (done)="onDone()" [currentContactsListId]="currentContactsListId"></app-add-contact>
        <app-edit-contact *ngSwitchCase="'edit'" (done)="onDone()"
          [currentContactsListId]="currentContactsListId" [contactId]="currentContactId"></app-edit-contact>
      </div>
    </div>
    <ng-template #elseBlock>
      Klicken Sie auf eine Kontaktliste
    </ng-template>
  `,
  styles: ['app-contacts { display: block; margin-top: 10px; }']
})
export class ContactsWrapperComponent implements OnChanges {
  contacts: Array<Contact> = [];
  display = 'list';
  currentContactId: string;

  @Input()
  currentContactsListId: string;

  constructor(private contactsService: ContactsService) {}

  ngOnChanges(changes: SimpleChanges) {
    this.contacts = this.contactsService.getContacts(
      changes.currentContactsListId.currentValue
    );
  }

  onAdd() {
    this.display = 'add';
  }

  onDone() {
    this.display = 'list';
    this.contacts = this.contactsService.getContacts(
      this.currentContactsListId
    );
  }

  onEdit(id: string) {
    this.display = 'edit';
    this.currentContactId = id;
  }
}
