import { Injectable } from '@angular/core';

export interface Contact {
  id?: string;
  name: string;
  tel?: string;
  email?: string;
}

@Injectable({
  providedIn: 'root'
})
export class ContactsService {
  private contactsForList = new Map<string, Array<Contact>>();

  constructor() {
    const privateContacts: Array<Contact> = [
      {
        id: '12',
        name: 'Max Mustermann',
        tel: '123456789',
        email: 'max@example.com'
      },
      {
        id: '13',
        name: 'Jane Doe',
        tel: '987654321',
        email: 'jane@example.com'
      }
    ];
    const businessContacts: Array<Contact> = [];

    this.contactsForList.set('1', privateContacts);
    this.contactsForList.set('2', businessContacts);
  }

  getContacts(listId: string) {
    if (this.contactsForList.has(listId)) {
      return this.contactsForList.get(listId);
    } else {
      return [];
    }
  }

  addContact(listId: string, contact: Contact) {
    if (this.contactsForList.has(listId)) {
      const contactsForList = this.contactsForList.get(listId);
      contact.id = String(contactsForList.length + 1);
      contactsForList.push(contact);
    } else {
      contact.id = '1';
      const contactsForList = [contact];
      this.contactsForList.set(String(this.contactsForList.size + 1), contactsForList);
    }
  }

  updateContact(listId: string, contactId: string, contact: Contact) {
    if (this.contactsForList.has(listId)) {
      const contactsForList = this.contactsForList.get(listId);

      for (let i = 0; i < contactsForList.length; i++) {
        if (contactsForList[i].id === contactId) {
          contactsForList[i] = contact;
          contactsForList[i].id = contactId;
        }
      }
    }
  }

  getContact(listId: string, contactId: string) {
    if (this.contactsForList.has(listId)) {
      const contactsForList = this.contactsForList.get(listId);

      for (let i = 0; i < contactsForList.length; i++) {
        if (contactsForList[i].id === contactId) {
          return contactsForList[i];
        }
      }
    }
  }
}
