import {
  Component,
  OnInit,
  Output,
  EventEmitter,
  OnDestroy
} from '@angular/core';
import { Subscription } from 'rxjs';

import { ContactsListsService, ContactsList } from './contacts-lists.service';

@Component({
  selector: 'app-contacts-lists-wrapper',
  template: `
    <div *ngIf="errorMessage" class="error">{{errorMessage}}</div>
    <div [ngSwitch]="display">
      <div *ngSwitchCase="'list'">
        <div class="btn-row">
          <button (click)="onAdd()">Hinzufügen</button>
        </div>
        <app-contacts-lists
          [contactsLists]="contactsLists"
          (selected)="selected.emit($event)"
          (edit)="onEdit($event)"
          (delete)="onDelete($event)"
        ></app-contacts-lists>
      </div>
      <app-add-contacts-list *ngSwitchCase="'add'" (done)="onDone()"></app-add-contacts-list>
      <app-edit-contacts-list *ngSwitchCase="'edit'" (done)="onDone()" [contactsListId]="currentContactsListId"></app-edit-contacts-list>
    </div>
  `,
  styles: ['app-contacts-lists { margin-top: 10px; display: block; }']
})
export class ContactsListsWrapperComponent implements OnInit, OnDestroy {
  @Output()
  selected = new EventEmitter<string>();

  contactsLists: Array<ContactsList> = [];
  display = 'list';
  currentContactsListId: string;
  errorMessage = '';

  getSubscription: Subscription;
  doneSubscription: Subscription;
  deleteSubscription: Subscription;
  getAfterDeleteSubscription: Subscription;

  constructor(private contactsListsService: ContactsListsService) {}

  ngOnInit() {
    this.getSubscription = this.getContactsLists();
  }

  ngOnDestroy() {
    this.getSubscription.unsubscribe();

    if (this.doneSubscription) {
      this.doneSubscription.unsubscribe();
    }

    if (this.deleteSubscription) {
      this.deleteSubscription.unsubscribe();
    }

    if (this.getAfterDeleteSubscription) {
      this.getAfterDeleteSubscription.unsubscribe();
    }
  }

  getContactsLists() {
    return this.contactsListsService.getContactsLists().subscribe(
      contactsLists => {
        this.contactsLists = contactsLists;
      },
      (err: Error) => {
        this.errorMessage = err.message;
      }
    );
  }

  onAdd() {
    this.display = 'add';
  }

  onDone() {
    this.display = 'list';
    this.doneSubscription = this.getContactsLists();
  }

  onEdit(id: string) {
    this.display = 'edit';
    this.currentContactsListId = id;
  }

  onDelete(id: string) {
    this.deleteSubscription = this.contactsListsService
      .deleteContactsList(id)
      .subscribe(
        () => {
          this.getAfterDeleteSubscription = this.getContactsLists();
        },
        (err: Error) => {
          this.errorMessage = err.message;
        }
      );
  }
}
