import { Component, Output, EventEmitter, OnDestroy } from '@angular/core';
import { Subscription } from 'rxjs';

import { ContactsList, ContactsListsService } from '../contacts-lists.service';

@Component({
  selector: 'app-add-contacts-list',
  template: `
    <div *ngIf="errorMessage" class="error">{{errorMessage}}</div>
    <app-contacts-list-form
      formTitle="Kontaktliste hinzufügen"
      submitBtnLabel="Hinzufügen"
      [contactsList]="contactsListTemplate"
      (formSubmit)="onSubmit($event)"
      (formCancel)="onCancel()"
    ></app-contacts-list-form>
  `
})
export class AddContactsListComponent implements OnDestroy {
  @Output()
  done = new EventEmitter();
  subscription: Subscription;

  contactsListTemplate: ContactsList = { name: '' };

  errorMessage = '';

  constructor(private contactsListsService: ContactsListsService) {}

  ngOnDestroy() {
    if (this.subscription) {
      this.subscription.unsubscribe();
    }
  }

  onSubmit(list: ContactsList) {
    this.subscription = this.contactsListsService
      .addContactsList(list)
      .subscribe(
        () => {
          this.done.emit();
        },
        (err: Error) => {
          this.errorMessage = err.message;
        }
      );
  }

  onCancel() {
    this.done.emit();
  }
}
