import {
  Component,
  Input,
  Output,
  EventEmitter,
  OnInit,
  OnDestroy
} from '@angular/core';
import { Subscription } from 'rxjs';

import { Contact, ContactsService } from '../contacts.service';

@Component({
  selector: 'app-edit-contact',
  template: `
    <div *ngIf="errorMessage" class="error">{{errorMessage}}</div>
    <app-contact-form
      *ngIf="contact"
      formTitle="Kontakt bearbeiten"
      submitBtnLabel="Aktualisieren"
      [contact]="contact"
      (formSubmit)="onSubmit($event)"
      (formCancel)="onCancel()"
    ></app-contact-form>
  `
})
export class EditContactComponent implements OnInit, OnDestroy {
  @Output()
  done = new EventEmitter();
  @Input()
  currentContactsListId: string;
  @Input()
  contactId: string;
  errorMessage = '';
  getSubscription: Subscription;
  updateSubscription: Subscription;

  contact: Contact;

  constructor(private contactsService: ContactsService) {}

  ngOnInit() {
    this.getSubscription = this.contactsService
      .getContact(this.currentContactsListId, this.contactId)
      .subscribe(
        contact => {
          this.contact = contact;
        },
        (err: Error) => {
          this.errorMessage = err.message;
        }
      );
  }

  ngOnDestroy() {
    this.getSubscription.unsubscribe();

    if (this.updateSubscription) {
      this.updateSubscription.unsubscribe();
    }
  }

  onSubmit(contact: Contact) {
    this.updateSubscription = this.contactsService
      .updateContact(this.currentContactsListId, this.contactId, contact)
      .subscribe(
        () => {
          this.done.emit();
        },
        (err: Error) => {
          this.errorMessage = err.message;
        }
      );
  }

  onCancel() {
    this.done.emit();
  }
}
