import {
  Component,
  Input,
  Output,
  EventEmitter,
  OnDestroy
} from '@angular/core';
import { Subscription } from 'rxjs';

import { Contact, ContactsService } from '../contacts.service';

@Component({
  selector: 'app-add-contact',
  template: `
    <div *ngIf="errorMessage" class="error">{{errorMessage}}</div>
    <app-contact-form
      formTitle="Kontakt hinzufügen"
      submitBtnLabel="Hinzufügen"
      [contact]="contactTemplate"
      (formSubmit)="onSubmit($event)"
      (formCancel)="onCancel()"
    ></app-contact-form>
  `
})
export class AddContactComponent implements OnDestroy {
  @Output()
  done = new EventEmitter();
  @Input()
  currentContactsListId: string;

  subscription: Subscription;

  contactTemplate: Contact = { name: '' };

  errorMessage = '';

  constructor(private contactsService: ContactsService) {}

  ngOnDestroy() {
    if (this.subscription) {
      this.subscription.unsubscribe();
    }
  }

  onSubmit(contact: Contact) {
    this.subscription = this.contactsService
      .addContact(this.currentContactsListId, contact)
      .subscribe(
        () => {
          this.done.emit();
        },
        (err: Error) => {
          this.errorMessage = err.message;
        }
      );
  }

  onCancel() {
    this.done.emit();
  }
}
