import { Component, Input, Output, EventEmitter, OnInit } from '@angular/core';
import { FormGroup, FormControl, Validators } from '@angular/forms';

import { Contact } from '../contacts.service';

@Component({
  selector: 'app-contact-form',
  templateUrl: './contact-form.component.html'
})
export class ContactFormComponent implements OnInit {
  @Input()
  formTitle = '';
  @Input()
  submitBtnLabel = '';
  @Input()
  contact: Contact;
  @Output()
  formSubmit = new EventEmitter<Contact>();
  @Output()
  formCancel = new EventEmitter();

  myForm: FormGroup;

  ngOnInit() {
    this.myForm = new FormGroup({
      name: new FormControl(this.contact.name, Validators.required),
      tel: new FormControl(this.contact.tel, Validators.pattern(/^\d+$/)),
      email: new FormControl(this.contact.email, Validators.pattern(/.+@.+/))
    });
  }

  onSubmit() {
    if (this.myForm.valid) {
      this.formSubmit.emit(this.myForm.value);
    }
  }

  onCancel() {
    this.formCancel.emit();
  }
}
