import { Component, OnInit, OnDestroy } from '@angular/core';
import { FormGroup, FormControl, Validators } from '@angular/forms';
import { Router } from '@angular/router';
import { Subscription } from 'rxjs';

import { LoginService } from './login.service';

@Component({
  templateUrl: './login.component.html',
  selector: 'app-login',
  styles: ['.login-form-wrapper { max-width: 320px; margin: auto; }']
})
export class LoginComponent implements OnInit, OnDestroy {
  myForm: FormGroup;
  errorMessage = '';
  subscription: Subscription;

  constructor(private loginService: LoginService, private router: Router) {}

  ngOnInit() {
    this.myForm = new FormGroup({
      username: new FormControl('', Validators.required),
      password: new FormControl('', Validators.required)
    });
  }

  ngOnDestroy() {
    if (this.subscription) {
      this.subscription.unsubscribe();
    }
  }

  onSubmit() {
    if (this.myForm.valid) {
      this.subscription = this.loginService
        .execLogin(this.myForm.value)
        .subscribe(
          () => {
            this.router.navigate(['/']);
          },
          err => {
            this.errorMessage = err.message;
          }
        );
    }
  }
}
