import { Injectable } from '@angular/core';
import { HttpClient, HttpErrorResponse } from '@angular/common/http';
import { catchError, mapTo } from 'rxjs/operators';
import { throwError, of } from 'rxjs';

const serverUrl = 'http://localhost:3000';

interface UserLogin {
  username: string;
  password: string;
}

@Injectable({
  providedIn: 'root'
})
export class LoginService {
  constructor(private http: HttpClient) {}

  handleError(err: HttpErrorResponse) {
    if (err.error instanceof ProgressEvent) {
      return throwError(new Error('Verbindungsfehler'));
    } else {
      switch (err.status) {
        case 400:
          return throwError(new Error('Fehlerhafte Daten'));
        case 401:
          return throwError(new Error('Passwort ist falsch'));
        case 404:
          return throwError(new Error('Benutzer nicht gefunden'));
        case 500:
          return throwError(new Error('Serverfehler'));
        default:
          return throwError(new Error('Unerwarteter Fehler'));
      }
    }
  }

  execLogin(data: UserLogin) {
    return this.http
      .post(serverUrl + '/login', data, { withCredentials: true })
      .pipe(catchError(this.handleError));
  }

  isLoggedIn() {
    return this.http.get(serverUrl + '/login', { withCredentials: true }).pipe(
      mapTo(true),
      catchError(() => of(false))
    );
  }
}
