import { TestBed } from '@angular/core/testing';
import { Router } from '@angular/router';
import { of } from 'rxjs';

import { LoginService } from './login.service';
import { AuthGuard } from './auth.guard';

describe('AuthGuard', () => {
  let loginService: jasmine.SpyObj<LoginService>;
  let router: Router;
  let authGuard: AuthGuard;

  beforeEach(() => {
    TestBed.configureTestingModule({
      providers: [
        {
          provide: LoginService,
          useValue: jasmine.createSpyObj('LoginService', ['isLoggedIn'])
        },
        {
          provide: Router,
          useValue: jasmine.createSpyObj('Router', ['navigate'])
        }
      ]
    });

    loginService = TestBed.get(LoginService);
    router = TestBed.get(Router);
    authGuard = TestBed.get(AuthGuard);
  });

  it('should return true if the user is logged in', () => {
    loginService.isLoggedIn.and.returnValue(of(true));

    authGuard.canActivate().subscribe(activate => {
      expect(activate).toBe(true);
    });
  });

  it('should return false and navigate to /login if the user is not logged in', () => {
    loginService.isLoggedIn.and.returnValue(of(false));

    authGuard.canActivate().subscribe(activate => {
      expect(activate).toBe(false);
      expect(router.navigate).toHaveBeenCalledWith(['/login']);
    });
  });
});
