import { ComponentFixture, TestBed } from '@angular/core/testing';
import { NO_ERRORS_SCHEMA } from '@angular/core';
import { By } from '@angular/platform-browser';
import { of, throwError } from 'rxjs';

import { AddContactsListComponent } from './add-contacts-list.component';
import { ContactsListsService } from '../contacts-lists.service';

describe('AddContactsListComponent', () => {
  let fixture: ComponentFixture<AddContactsListComponent>;
  let addContactsListComponent: AddContactsListComponent;
  let contactsListsService: jasmine.SpyObj<ContactsListsService>;

  beforeEach(() => {
    TestBed.configureTestingModule({
      declarations: [AddContactsListComponent],
      providers: [
        {
          provide: ContactsListsService,
          useValue: jasmine.createSpyObj('ContactsService', ['addContactsList'])
        }
      ],
      schemas: [NO_ERRORS_SCHEMA]
    });

    contactsListsService = TestBed.get(ContactsListsService);

    fixture = TestBed.createComponent(AddContactsListComponent);
    addContactsListComponent = fixture.componentInstance;
  });

  it('should call addContactsList on submit', () => {
    contactsListsService.addContactsList.and.returnValue(of(''));
    const data = { name: 'abc' };

    addContactsListComponent.onSubmit(data);

    expect(contactsListsService.addContactsList).toHaveBeenCalledWith(data);
  });

  it('should emit done if the addContactsList call was successful', () => {
    contactsListsService.addContactsList.and.returnValue(of(''));

    const data = { name: 'abc' };

    const doneSpy = spyOn(addContactsListComponent.done, 'emit');

    addContactsListComponent.onSubmit(data);

    expect(doneSpy).toHaveBeenCalled();
  });

  it('should show an error message if the addContactsList call failed', () => {
    const msg = 'SOME_ERROR';
    contactsListsService.addContactsList.and.returnValue(
      throwError(new Error(msg))
    );

    const data = { name: 'abc' };

    addContactsListComponent.onSubmit(data);

    fixture.detectChanges();

    const elem = fixture.debugElement.query(By.css('.error'));

    expect(elem.nativeElement.textContent).toContain(msg);
  });

  it('should unsubscribe the subscription on destroy', () => {
    const data = { name: 'abc' };
    contactsListsService.addContactsList.and.returnValue(of(''));

    addContactsListComponent.onSubmit(data);

    const unsubscribeSpy = spyOn(
      addContactsListComponent.subscription,
      'unsubscribe'
    ).and.callThrough();

    addContactsListComponent.ngOnDestroy();

    expect(unsubscribeSpy).toHaveBeenCalled();
  });

  it('should emit done onCancel', () => {
    const doneSpy = spyOn(addContactsListComponent.done, 'emit');

    addContactsListComponent.onCancel();

    expect(doneSpy).toHaveBeenCalled();
  });
});
