import { ComponentFixture, TestBed } from '@angular/core/testing';
import { By } from '@angular/platform-browser';

import { ContactsListsComponent } from './contacts-lists.component';
import { ContactsListComponent } from './contacts-list.component';

describe('ContactsListsComponent', () => {
  let fixture: ComponentFixture<ContactsListsComponent>;
  let contactsListsComponent: ContactsListsComponent;

  beforeEach(() => {
    TestBed.configureTestingModule({
      declarations: [ContactsListsComponent, ContactsListComponent]
    });

    fixture = TestBed.createComponent(ContactsListsComponent);
    contactsListsComponent = fixture.componentInstance;
  });

  it('should emit edit when ContactsListComponent emits edit', () => {
    const id = '123';

    contactsListsComponent.contactsLists = [{ id: id, name: 'foo' }];
    fixture.detectChanges();

    const elem = fixture.debugElement.query(
      By.directive(ContactsListComponent)
    );

    expect(elem).not.toBeNull();

    contactsListsComponent.edit.subscribe((i: string) => {
      expect(i).toBe(id);
    });

    elem.componentInstance.edit.emit(id);
  });

  it('should emit delete when ContactsListComponent emits delete', () => {
    const id = '123';

    contactsListsComponent.contactsLists = [{ id: id, name: 'foo' }];
    fixture.detectChanges();

    const elem = fixture.debugElement.query(
      By.directive(ContactsListComponent)
    );

    expect(elem).not.toBeNull();

    contactsListsComponent.delete.subscribe((i: string) => {
      expect(i).toBe(id);
    });

    elem.componentInstance.delete.emit(id);
  });

  it('should emit selected when ContactsListComponent emits selected', () => {
    const id = '123';

    contactsListsComponent.contactsLists = [{ id: id, name: 'foo' }];
    fixture.detectChanges();

    const elem = fixture.debugElement.query(
      By.directive(ContactsListComponent)
    );

    expect(elem).not.toBeNull();

    contactsListsComponent.selected.subscribe((i: string) => {
      expect(i).toBe(id);
    });

    elem.componentInstance.selected.emit(id);
  });

  it('should return the id of the given contact', () => {
    const contact = { id: '123', name: 'foo' };

    const res = contactsListsComponent.getId(0, contact);

    expect(res).toBe(contact.id);
  });
});
