import {
  Component,
  Input,
  Output,
  EventEmitter,
  OnInit,
  OnDestroy
} from '@angular/core';
import { Subscription } from 'rxjs';

import { ContactsList, ContactsListsService } from '../contacts-lists.service';

@Component({
  selector: 'app-edit-contacts-list',
  template: `
    <div *ngIf="errorMessage" class="error">{{errorMessage}}</div>
    <app-contacts-list-form
      *ngIf="contactsList"
      formTitle="Kontaktliste bearbeiten"
      submitBtnLabel="Aktualisieren"
      [contactsList]="contactsList"
      (formSubmit)="onSubmit($event)"
      (formCancel)="onCancel()"
    ></app-contacts-list-form>
  `
})
export class EditContactsListComponent implements OnInit, OnDestroy {
  @Output()
  done = new EventEmitter();
  @Input()
  contactsListId: string;
  errorMessage = '';
  getSubscription: Subscription;
  updateSubscription: Subscription;

  contactsList: ContactsList;

  constructor(private contactsListsService: ContactsListsService) {}

  ngOnInit() {
    this.getSubscription = this.contactsListsService
      .getContactsList(this.contactsListId)
      .subscribe(
        contactsList => {
          this.contactsList = contactsList;
        },
        (err: Error) => {
          this.errorMessage = err.message;
        }
      );
  }

  ngOnDestroy() {
    this.getSubscription.unsubscribe();

    if (this.updateSubscription) {
      this.updateSubscription.unsubscribe();
    }
  }

  onSubmit(list: ContactsList) {
    this.updateSubscription = this.contactsListsService
      .updateContactsList(this.contactsListId, list)
      .subscribe(
        () => {
          this.done.emit();
        },
        (err: Error) => {
          this.errorMessage = err.message;
        }
      );
  }

  onCancel() {
    this.done.emit();
  }
}
