import { ComponentFixture, TestBed } from '@angular/core/testing';
import { By } from '@angular/platform-browser';
import { FormGroupDirective, ReactiveFormsModule } from '@angular/forms';

import { ContactFormComponent } from './contact-form.component';

describe('ContactFormComponent', () => {
  let fixture: ComponentFixture<ContactFormComponent>;
  let contactFormComponent: ContactFormComponent;

  beforeEach(() => {
    TestBed.configureTestingModule({
      imports: [ReactiveFormsModule],
      declarations: [ContactFormComponent]
    });

    fixture = TestBed.createComponent(ContactFormComponent);
    contactFormComponent = fixture.componentInstance;
  });

  it('should emit formSubmit with the form data on submit if the form is valid', () => {
    const data = { name: 'abc', email: '', tel: '' };
    contactFormComponent.contact = data;
    contactFormComponent.ngOnInit();

    const formSubmitSpy = spyOn(contactFormComponent.formSubmit, 'emit');

    contactFormComponent.onSubmit();

    expect(contactFormComponent.myForm.valid).toBe(true);
    expect(formSubmitSpy).toHaveBeenCalledWith(data);
  });

  it('should not emit formSubmit if the form is invalid', () => {
    const data = { name: '', email: '', tel: '' };
    contactFormComponent.contact = data;
    contactFormComponent.ngOnInit();

    const formSubmitSpy = spyOn(contactFormComponent.formSubmit, 'emit');

    contactFormComponent.onSubmit();

    expect(contactFormComponent.myForm.invalid).toBe(true);
    expect(formSubmitSpy).not.toHaveBeenCalledWith(data);
  });

  it('should emit formCancel onCancel', () => {
    const formCancelSpy = spyOn(contactFormComponent.formCancel, 'emit');

    contactFormComponent.onCancel();

    expect(formCancelSpy).toHaveBeenCalled();
  });

  it('should show an error message if the name is invalid and the form submitted', () => {
    // setup form
    contactFormComponent.contact = { name: '', email: '', tel: '' };
    contactFormComponent.ngOnInit();

    fixture.detectChanges();

    const form = fixture.debugElement.query(By.directive(FormGroupDirective));
    form.triggerEventHandler('submit', null);

    fixture.detectChanges();

    // Zugriff auf das erste Element mit der form-error Klasse
    const elem = fixture.debugElement.query(By.css('.form-error'));

    expect(elem.nativeElement.textContent).toContain('Pflichtfeld');
  });

  it('should show an error message if the email is invalid and the form submitted', () => {
    // setup form
    contactFormComponent.contact = { name: 'abc', email: 'abc', tel: '' };
    contactFormComponent.ngOnInit();

    fixture.detectChanges();

    const form = fixture.debugElement.query(By.directive(FormGroupDirective));
    form.triggerEventHandler('submit', null);

    fixture.detectChanges();

    // Zugriff auf das zweite Element mit der form-error Klasse
    const elem = fixture.debugElement.queryAll(By.css('.form-error'))[1];

    expect(elem.nativeElement.textContent).toContain(
      'Ungültige E-Mail-Adresse'
    );
  });

  it('should show an error message if the tel is invalid and the form submitted', () => {
    // setup form
    contactFormComponent.contact = { name: 'abc', email: '', tel: 'abc' };
    contactFormComponent.ngOnInit();

    fixture.detectChanges();

    const form = fixture.debugElement.query(By.directive(FormGroupDirective));
    form.triggerEventHandler('submit', null);

    fixture.detectChanges();

    // Zugriff auf das dritte Element mit der form-error Klasse
    const elem = fixture.debugElement.queryAll(By.css('.form-error'))[2];

    expect(elem.nativeElement.textContent).toContain('Ungültige Telefonnummer');
  });
});
