import { ComponentFixture, TestBed } from '@angular/core/testing';
import { By } from '@angular/platform-browser';

import { ContactsComponent } from './contacts.component';
import { ContactComponent } from './contact.component';

describe('ContactsComponent', () => {
  let fixture: ComponentFixture<ContactsComponent>;
  let contactsComponent: ContactsComponent;

  beforeEach(() => {
    TestBed.configureTestingModule({
      declarations: [ContactsComponent, ContactComponent]
    });

    fixture = TestBed.createComponent(ContactsComponent);
    contactsComponent = fixture.componentInstance;
  });

  it('should show a message if we have no contacts', () => {
    contactsComponent.contacts = [];

    fixture.detectChanges();

    const elem = fixture.debugElement.query(By.css('div'));

    expect(elem.nativeElement.textContent).toContain('Keine Kontakte');
  });

  it('should emit edit when ContactComponent emits edit', () => {
    const id = '123';

    contactsComponent.contacts = [{ id: id, name: 'foo' }];
    fixture.detectChanges();

    const elem = fixture.debugElement.query(By.directive(ContactComponent));

    expect(elem).not.toBeNull();

    contactsComponent.edit.subscribe((i: string) => {
      expect(i).toBe(id);
    });

    elem.componentInstance.edit.emit(id);
  });

  it('should emit delete when ContactComponent emits delete', () => {
    const id = '123';

    contactsComponent.contacts = [{ id: id, name: 'foo' }];
    fixture.detectChanges();

    const elem = fixture.debugElement.query(By.directive(ContactComponent));

    expect(elem).not.toBeNull();

    contactsComponent.delete.subscribe((i: string) => {
      expect(i).toBe(id);
    });

    elem.componentInstance.delete.emit(id);
  });

  it('should return the id of the given contact', () => {
    const contact = { id: '123', name: 'foo' };

    const res = contactsComponent.getId(0, contact);

    expect(res).toBe(contact.id);
  });
});
