import { Injectable } from '@angular/core';
import { HttpClient, HttpErrorResponse } from '@angular/common/http';
import { throwError } from 'rxjs';
import { catchError } from 'rxjs/operators';

export interface ContactsList {
  id?: string;
  name: string;
}

const serverUrl = 'http://localhost:3000';

@Injectable({
  providedIn: 'root'
})
export class ContactsListsService {
  constructor(private http: HttpClient) {}

  handleError(err: HttpErrorResponse) {
    if (err.error instanceof ProgressEvent) {
      return throwError(new Error('Verbindungsfehler'));
    } else {
      switch (err.status) {
        case 400:
          return throwError(new Error('Fehlerhafte Daten'));
        case 404:
          return throwError(new Error('Nicht gefunden'));
        case 500:
          return throwError(new Error('Serverfehler'));
        default:
          return throwError(new Error('Unerwarteter Fehler'));
      }
    }
  }

  getContactsLists() {
    return this.http
      .get<Array<ContactsList>>(serverUrl + '/lists')
      .pipe(catchError(this.handleError));
  }

  addContactsList(list: ContactsList) {
    return this.http
      .post(serverUrl + '/lists', list)
      .pipe(catchError(this.handleError));
  }

  updateContactsList(listId: string, list: ContactsList) {
    return this.http
      .put(serverUrl + '/lists/' + listId, list)
      .pipe(catchError(this.handleError));
  }

  getContactsList(listId: string) {
    return this.http
      .get<ContactsList>(serverUrl + '/lists/' + listId)
      .pipe(catchError(this.handleError));
  }

  deleteContactsList(listId: string) {
    return this.http
      .delete(serverUrl + '/lists/' + listId)
      .pipe(catchError(this.handleError));
  }
}
