import { ComponentFixture, TestBed } from '@angular/core/testing';
import { By } from '@angular/platform-browser';
import { FormGroupDirective, ReactiveFormsModule } from '@angular/forms';

import { ContactsListFormComponent } from './contacts-list-form.component';

describe('ContactsListFormComponent', () => {
  let fixture: ComponentFixture<ContactsListFormComponent>;
  let contactsListFormComponent: ContactsListFormComponent;

  beforeEach(() => {
    TestBed.configureTestingModule({
      imports: [ReactiveFormsModule],
      declarations: [ContactsListFormComponent]
    });

    fixture = TestBed.createComponent(ContactsListFormComponent);
    contactsListFormComponent = fixture.componentInstance;
  });

  it('should emit formSubmit with the form data on submit if the form is valid', () => {
    const data = { name: 'abc' };
    contactsListFormComponent.contactsList = data;
    contactsListFormComponent.ngOnInit();

    const formSubmitSpy = spyOn(contactsListFormComponent.formSubmit, 'emit');

    contactsListFormComponent.onSubmit();

    expect(contactsListFormComponent.myForm.valid).toBe(true);
    expect(formSubmitSpy).toHaveBeenCalledWith(data);
  });

  it('should not emit formSubmit if the form is invalid', () => {
    const data = { name: '' };
    contactsListFormComponent.contactsList = data;
    contactsListFormComponent.ngOnInit();

    const formSubmitSpy = spyOn(contactsListFormComponent.formSubmit, 'emit');

    contactsListFormComponent.onSubmit();

    expect(contactsListFormComponent.myForm.invalid).toBe(true);
    expect(formSubmitSpy).not.toHaveBeenCalledWith(data);
  });

  it('should emit formCancel onCancel', () => {
    const formCancelSpy = spyOn(contactsListFormComponent.formCancel, 'emit');

    contactsListFormComponent.onCancel();

    expect(formCancelSpy).toHaveBeenCalled();
  });

  it('should show an error message if the name is invalid and the form submitted', () => {
    // setup form
    contactsListFormComponent.contactsList = { name: '' };
    contactsListFormComponent.ngOnInit();

    fixture.detectChanges();

    const form = fixture.debugElement.query(By.directive(FormGroupDirective));
    form.triggerEventHandler('submit', null);

    fixture.detectChanges();

    const elem = fixture.debugElement.query(By.css('.form-error'));

    expect(elem.nativeElement.textContent).toContain('Pflichtfeld');
  });
});
