import { Injectable } from '@angular/core';
import { HttpClient, HttpErrorResponse } from '@angular/common/http';
import { throwError } from 'rxjs';
import { catchError } from 'rxjs/operators';

export interface Contact {
  id?: string;
  name: string;
  tel?: string;
  email?: string;
}

const serverUrl = 'http://localhost:3000';

@Injectable({
  providedIn: 'root'
})
export class ContactsService {
  constructor(private http: HttpClient) {}

  private getUrl(listId: string, contactId?: string) {
    const url = serverUrl + '/lists/' + listId + '/contacts';

    if (contactId) {
      return url + '/' + contactId;
    } else {
      return url;
    }
  }

  handleError(err: HttpErrorResponse) {
    if (err.error instanceof ProgressEvent) {
      return throwError(new Error('Verbindungsfehler'));
    } else {
      switch (err.status) {
        case 400:
          return throwError(new Error('Fehlerhafte Daten'));
        case 404:
          return throwError(new Error('Nicht gefunden'));
        case 500:
          return throwError(new Error('Serverfehler'));
        default:
          return throwError(new Error('Unerwarteter Fehler'));
      }
    }
  }

  getContacts(listId: string) {
    return this.http
      .get<Array<Contact>>(this.getUrl(listId))
      .pipe(catchError(this.handleError));
  }

  addContact(listId: string, contact: Contact) {
    return this.http
      .post(this.getUrl(listId), contact)
      .pipe(catchError(this.handleError));
  }

  updateContact(listId: string, contactId: string, contact: Contact) {
    return this.http
      .put(this.getUrl(listId, contactId), contact)
      .pipe(catchError(this.handleError));
  }

  getContact(listId: string, contactId: string) {
    return this.http
      .get<Contact>(this.getUrl(listId, contactId))
      .pipe(catchError(this.handleError));
  }

  deleteContact(listId: string, contactId: string) {
    return this.http
      .delete(this.getUrl(listId, contactId))
      .pipe(catchError(this.handleError));
  }
}
