import { ComponentFixture, TestBed } from '@angular/core/testing';
import { NO_ERRORS_SCHEMA } from '@angular/core';
import { By } from '@angular/platform-browser';
import { of, throwError } from 'rxjs';

import { AddContactComponent } from './add-contact.component';
import { ContactsService } from '../contacts.service';

describe('AddContactComponent', () => {
  let fixture: ComponentFixture<AddContactComponent>;
  let addContactComponent: AddContactComponent;
  let contactsService: jasmine.SpyObj<ContactsService>;

  beforeEach(() => {
    TestBed.configureTestingModule({
      declarations: [AddContactComponent],
      providers: [
        {
          provide: ContactsService,
          useValue: jasmine.createSpyObj('ContactsService', ['addContact'])
        }
      ],
      schemas: [NO_ERRORS_SCHEMA]
    });

    contactsService = TestBed.get(ContactsService);

    fixture = TestBed.createComponent(AddContactComponent);
    addContactComponent = fixture.componentInstance;
  });

  it('should call addContact on submit', () => {
    contactsService.addContact.and.returnValue(of(''));

    const id = '123';
    const data = { name: 'abc' };

    addContactComponent.currentContactsListId = id;

    addContactComponent.onSubmit(data);

    expect(contactsService.addContact).toHaveBeenCalledWith(id, data);
  });

  it('should emit done if the addContact call was successful', () => {
    contactsService.addContact.and.returnValue(of(''));

    const id = '123';
    const data = { name: 'abc' };

    addContactComponent.currentContactsListId = id;

    const doneSpy = spyOn(addContactComponent.done, 'emit');

    addContactComponent.onSubmit(data);

    expect(doneSpy).toHaveBeenCalled();
  });

  it('should show an error message if the addContact call failed', () => {
    const msg = 'SOME_ERROR';
    contactsService.addContact.and.returnValue(throwError(new Error(msg)));

    const id = '123';
    const data = { name: 'abc' };

    addContactComponent.currentContactsListId = id;

    addContactComponent.onSubmit(data);

    fixture.detectChanges();

    const elem = fixture.debugElement.query(By.css('.error'));

    expect(elem.nativeElement.textContent).toContain(msg);
  });

  it('should unsubscribe the subscription on destroy', () => {
    const id = '123';
    const data = { name: 'abc' };

    addContactComponent.currentContactsListId = id;

    contactsService.addContact.and.returnValue(of(''));

    addContactComponent.onSubmit(data);

    const unsubscribeSpy = spyOn(
      addContactComponent.subscription,
      'unsubscribe'
    ).and.callThrough();

    addContactComponent.ngOnDestroy();

    expect(unsubscribeSpy).toHaveBeenCalled();
  });

  it('should emit done onCancel', () => {
    const doneSpy = spyOn(addContactComponent.done, 'emit');

    addContactComponent.onCancel();

    expect(doneSpy).toHaveBeenCalled();
  });
});
