import { Component, OnInit } from '@angular/core';
import {
  FormGroup,
  FormControl,
  AbstractControl,
  ValidationErrors,
  ValidatorFn
} from '@angular/forms';

function containsNumber(control: AbstractControl): ValidationErrors | null {
  if (control.value) {
    return /\d/.test(control.value) ? null : { containsnumber: true };
  }

  return null;
}

function containsLetter(letter: string): ValidatorFn {
  return (control: AbstractControl) => {
    if (control.value) {
      return control.value.indexOf(letter) !== -1
        ? null
        : { containsletter: { letter: letter, value: control.value } };
    }

    return null;
  };
}

@Component({
  selector: 'app-root',
  templateUrl: './app.component.html'
})
export class AppComponent implements OnInit {
  myForm: FormGroup;

  ngOnInit() {
    this.myForm = new FormGroup({
      containsNumberField: new FormControl('', {
        validators: [containsNumber]
      }),
      containsLetterField: new FormControl('', {
        validators: [containsLetter('a')]
      })
    });
  }

  onSubmit() {
    console.log('containsNumberField:', this.myForm.value.containsNumberField);
    console.log('containsLetterField:', this.myForm.value.containsLetterField);
    if (this.myForm.valid) {
      console.log('Gültig');
    } else {
      console.log('Ungültig');
    }
  }
}
