class DB {
  constructor(db) {
    this.lists = db;
  }

  // List methods
  getOneList(listID) {
    return { ...this.lists.getById(listID).value(), contacts: undefined };
  }

  getAllLists() {
    return this.lists.value().map(list => ({ ...list, contacts: undefined }));
  }

  addList(data) {
    const list = this.lists.insert({ ...data, contacts: [] }).write();

    return { ...list, contacts: undefined };
  }

  hasList(listID) {
    return Boolean(this.lists.find({ id: listID }).value());
  }

  updateList(listID, data) {
    this.lists.updateById(listID, { ...data, id: listID }).write();
  }

  deleteList(listID) {
    this.lists.removeById(listID).write();
  }

  // Contacts methods
  getOneContact(listID, contactID) {
    return this.lists
      .getById(listID)
      .get('contacts')
      .getById(contactID)
      .value();
  }

  getAllContacts(listID) {
    return this.lists
      .getById(listID)
      .get('contacts')
      .value();
  }

  hasContact(listID, contactID) {
    return Boolean(
      this.lists
        .getById(listID)
        .get('contacts')
        .find({ id: contactID })
        .value()
    );
  }

  addContact(listID, data) {
    return this.lists
      .getById(listID)
      .get('contacts')
      .insert(data)
      .write();
  }

  updateContact(listID, contactID, data) {
    this.lists
      .getById(listID)
      .get('contacts')
      .updateById(contactID, { ...data, id: contactID })
      .write();
  }

  deleteContact(listID, contactID) {
    this.lists
      .getById(listID)
      .get('contacts')
      .removeById(contactID)
      .write();
  }
}

module.exports = DB;
