const send = require('./../helpers/sender_functions');

function setupContactsHandlers(db) {
  // List functions
  function getOneList(req, res) {
    const list = db.getOneList(req.params.listID);
    if (list) {
      send.jsonContent(res, list);
    } else {
      send.notFound(res);
    }
  }

  function getAllLists(req, res) {
    send.jsonContent(res, db.getAllLists());
  }

  function addList(req, res) {
    const { body } = req;

    if (!body || Object.keys(body).length === 0) {
      return send.badRequest(res);
    }

    send.jsonContent(res, db.addList(body));
  }

  function updateList(req, res) {
    const { listID } = req.params;
    const { body } = req;

    if (!body || Object.keys(body).length === 0) {
      return send.badRequest(res);
    }

    if (db.hasList(listID)) {
      db.updateList(listID, body);
      send.jsonContent(res, {});
    } else {
      send.notFound(res);
    }
  }

  function deleteList(req, res) {
    const { listID } = req.params;

    if (db.hasList(listID)) {
      db.deleteList(listID);
      send.jsonContent(res, {});
    } else {
      send.notFound(res);
    }
  }

  // Contacts functions
  function getOneContact(req, res) {
    const { listID, contactID } = req.params;

    if (db.hasList(listID)) {
      const contact = db.getOneContact(listID, contactID);
      if (contact) {
        send.jsonContent(res, contact);
      } else {
        send.notFound(res);
      }
    } else {
      send.notFound(res);
    }
  }

  function getAllContacts(req, res) {
    const { listID } = req.params;

    if (db.hasList(listID)) {
      send.jsonContent(res, db.getAllContacts(listID));
    } else {
      send.notFound(res);
    }
  }

  function addContact(req, res) {
    const { listID } = req.params;
    const { body } = req;

    if (!body || Object.keys(body).length === 0) {
      return send.badRequest(res);
    }

    if (db.hasList(listID)) {
      send.jsonContent(res, db.addContact(listID, body));
    } else {
      send.notFound(res);
    }
  }

  function updateContact(req, res) {
    const { listID, contactID } = req.params;
    const { body } = req;

    if (!body || Object.keys(body).length === 0) {
      return send.badRequest(res);
    }

    if (db.hasList(listID)) {
      if (db.hasContact(listID, contactID)) {
        db.updateContact(listID, contactID, body);
        send.jsonContent(res, {});
      } else {
        send.notFound(res);
      }
    } else {
      send.notFound(res);
    }
  }

  function deleteContact(req, res) {
    const { listID, contactID } = req.params;

    if (db.hasList(listID)) {
      if (db.hasContact(listID, contactID)) {
        db.deleteContact(listID, contactID);
        send.jsonContent(res, {});
      } else {
        send.notFound(res);
      }
    } else {
      send.notFound(res);
    }
  }

  return {
    getOneList,
    getAllLists,
    addList,
    updateList,
    deleteList,
    getOneContact,
    getAllContacts,
    addContact,
    updateContact,
    deleteContact
  };
}

module.exports = setupContactsHandlers;
