'use strict';

const OK_STATUS_TEXT = 'OK';
const OK_STATUS_CODE = 200;
const BAD_REQUEST_TEXT = 'BAD REQUEST';
const BAD_REQUEST_CODE = 400;
const UNAUTHORIZED_STATUS_TEXT = 'UNAUTHORIZED';
const UNAUTHORIZED_STATUS_CODE = 401;
const NOT_FOUND_TEXT = 'NOT FOUND';
const NOT_FOUND_CODE = 404;
const ERROR_STATUS_TEXT = 'INTERNAL ERROR';
const ERROR_STATUS_CODE = 500;

const CONTENT_TYPE = 'application/json;charset=UTF-8';
const CHAR_SET = 'utf8';

function send(res, content, statusCode, statusText) {
  const data = JSON.stringify(content);
  const dataLength = Buffer.byteLength(data, CHAR_SET);
  const headers = {
    'Content-Length': dataLength,
    'Content-Type': CONTENT_TYPE
  };
  res.writeHead(statusCode, statusText, headers);
  res.end(data, CHAR_SET);
}

function sendJsonContent(res, content) {
  send(res, content, OK_STATUS_CODE, OK_STATUS_TEXT);
}

function sendError(res, content) {
  send(res, content, ERROR_STATUS_CODE, ERROR_STATUS_TEXT);
}

function sendUnauthorized(res) {
  send(res, {}, UNAUTHORIZED_STATUS_CODE, UNAUTHORIZED_STATUS_TEXT);
}

function sendNotFound(res) {
  send(res, {}, NOT_FOUND_CODE, NOT_FOUND_TEXT);
}

function sendBadRequest(res) {
  send(res, {}, BAD_REQUEST_CODE, BAD_REQUEST_TEXT);
}

module.exports = {
  jsonContent: sendJsonContent,
  error: sendError,
  unauthorized: sendUnauthorized,
  notFound: sendNotFound,
  badRequest: sendBadRequest
};
