const path = require('path');
const low = require('lowdb');
const lodashId = require('lodash-id');
const FileSync = require('lowdb/adapters/FileSync');

const ContactsDB = require('./dbs/contacts_db');
const startServer = require('./server');

const setupUserHandlers = require('./handlers/user_handlers');
const setupContactsHandlers = require('./handlers/contacts_handlers');

const adapter = new FileSync(path.resolve(__dirname, '../db/db.json'));
const db = low(adapter);

db._.mixin(lodashId);

db.defaults({ lists: [] }).write();

function init() {
  const contactsDB = new ContactsDB(db.get('lists'));

  const handlers = {
    userHandlers: setupUserHandlers(),
    contactsHandlers: setupContactsHandlers(contactsDB)
  };

  startServer(handlers);
}

module.exports = init;
