'use strict';

const http = require('http');
const bodyParser = require('body-parser');
const cors = require('cors');
const express = require('express');
const expressSession = require('express-session');

const setupRoutes = require('./routes');
const send = require('./helpers/sender_functions');

function startServer(handlers) {
  const expressApp = express();

  expressApp.set('port', 3000);
  expressApp.set('x-powered-by', false);

  expressApp.use(cors({ credentials: true, origin: true }));
  expressApp.use(bodyParser.json());
  expressApp.use(
    expressSession({
      resave: false,
      saveUninitialized: false,
      secret: 'This is a secret'
    })
  );

  // Routes
  setupRoutes(expressApp, handlers);

  expressApp.use(function(req, res) {
    send.notFound(res);
  });

  // Error handler
  expressApp.use(function(err, req, res, next) {
    // eslint-disable-line no-unused-vars
    send.error(res, {
      name: err.name,
      errorMessage: err.message
    });
  });

  http.createServer(expressApp).listen(expressApp.get('port'), () => {
    console.log('Der Server ist gestartet');
  });
}

module.exports = startServer;
